<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Indiana";
    var qsoPartyUrl = "http://www.hdxcc.org/inqp";
    var overlayUrl = "http://www.no5w.com/OverlayIndianaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "ada");
  countySelection.options[1] = new Option("Allen", "all");
  countySelection.options[2] = new Option("Bartholomew", "bar");
  countySelection.options[3] = new Option("Benton", "ben");
  countySelection.options[4] = new Option("Blackford", "bla");
  countySelection.options[5] = new Option("Boone", "boo");
  countySelection.options[6] = new Option("Brown", "bro");
  countySelection.options[7] = new Option("Carroll", "car");
  countySelection.options[8] = new Option("Cass", "cas");
  countySelection.options[9] = new Option("Clark", "clar");
  countySelection.options[10] = new Option("Clay", "clay");
  countySelection.options[11] = new Option("Clinton", "cli");
  countySelection.options[12] = new Option("Crawford", "cra");
  countySelection.options[13] = new Option("Daviess", "dav");
  countySelection.options[14] = new Option("Dearborn", "dea");
  countySelection.options[15] = new Option("Decatur", "dec");
  countySelection.options[16] = new Option("DeKalb", "dek");
  countySelection.options[17] = new Option("Delaware", "del");
  countySelection.options[18] = new Option("Dubois", "dub");
  countySelection.options[19] = new Option("Elkhart", "elk");
  countySelection.options[20] = new Option("Fayette", "fay");
  countySelection.options[21] = new Option("Floyd", "flo");
  countySelection.options[22] = new Option("Fountain", "fou");
  countySelection.options[23] = new Option("Franklin", "fra");
  countySelection.options[24] = new Option("Fulton", "ful");
  countySelection.options[25] = new Option("Gibson", "gib");
  countySelection.options[26] = new Option("Grant", "gra");
  countySelection.options[27] = new Option("Greene", "gre");
  countySelection.options[28] = new Option("Hamilton", "ham");
  countySelection.options[29] = new Option("Hancock", "han");
  countySelection.options[30] = new Option("Harrison", "har");
  countySelection.options[31] = new Option("Hendricks", "hend");
  countySelection.options[32] = new Option("Henry", "henr");
  countySelection.options[33] = new Option("Howard", "how");
  countySelection.options[34] = new Option("Huntington", "hun");
  countySelection.options[35] = new Option("Jackson", "jac");
  countySelection.options[36] = new Option("Jasper", "jas");
  countySelection.options[37] = new Option("Jay", "jay");
  countySelection.options[38] = new Option("Jefferson", "jef");
  countySelection.options[39] = new Option("Jennings", "jen");
  countySelection.options[40] = new Option("Johnson", "joh");
  countySelection.options[41] = new Option("Knox", "kno");
  countySelection.options[42] = new Option("Kosciusko", "kos");
  countySelection.options[43] = new Option("Lagrange", "lag");
  countySelection.options[44] = new Option("Lake", "lak");
  countySelection.options[45] = new Option("LaPorte", "lap");
  countySelection.options[46] = new Option("Lawrence", "law");
  countySelection.options[47] = new Option("Madison", "mad");
  countySelection.options[48] = new Option("Marion", "mari");
  countySelection.options[49] = new Option("Marshall", "mars");
  countySelection.options[50] = new Option("Martin", "mart");
  countySelection.options[51] = new Option("Miami", "mia");
  countySelection.options[52] = new Option("Monroe", "monr");
  countySelection.options[53] = new Option("Montgomery", "mont");
  countySelection.options[54] = new Option("Morgan", "mor");
  countySelection.options[55] = new Option("Newton", "new");
  countySelection.options[56] = new Option("Noble", "nob");
  countySelection.options[57] = new Option("Ohio", "ohi");
  countySelection.options[58] = new Option("Orange", "ora");
  countySelection.options[59] = new Option("Owen", "owe");
  countySelection.options[60] = new Option("Parke", "par");
  countySelection.options[61] = new Option("Perry", "per");
  countySelection.options[62] = new Option("Pike", "pik");
  countySelection.options[63] = new Option("Porter", "por");
  countySelection.options[64] = new Option("Posey", "pos");
  countySelection.options[65] = new Option("Pulaski", "pul");
  countySelection.options[66] = new Option("Putnam", "put");
  countySelection.options[67] = new Option("Randolph", "ran");
  countySelection.options[68] = new Option("Ripley", "rip");
  countySelection.options[69] = new Option("Rush", "rus");
  countySelection.options[70] = new Option("Scott", "sco");
  countySelection.options[71] = new Option("Shelby", "she");
  countySelection.options[72] = new Option("Spencer", "spe");
  countySelection.options[73] = new Option("St.Joseph", "stj");
  countySelection.options[74] = new Option("Starke", "sta");
  countySelection.options[75] = new Option("Steuben", "ste");
  countySelection.options[76] = new Option("Sullivan", "sul");
  countySelection.options[77] = new Option("Switzerland", "swi");
  countySelection.options[78] = new Option("Tippecanoe", "tipp");
  countySelection.options[79] = new Option("Tipton", "tipt");
  countySelection.options[80] = new Option("Union", "uni");
  countySelection.options[81] = new Option("Vanderburgh", "van");
  countySelection.options[82] = new Option("Vermillion", "ver");
  countySelection.options[83] = new Option("Vigo", "vig");
  countySelection.options[84] = new Option("Wabash", "wab");
  countySelection.options[85] = new Option("Warren", "warn");
  countySelection.options[86] = new Option("Warrick", "wark");
  countySelection.options[87] = new Option("Washington", "was");
  countySelection.options[88] = new Option("Wayne", "way");
  countySelection.options[89] = new Option("Wells", "wel");
  countySelection.options[90] = new Option("White", "whte");
  countySelection.options[91] = new Option("Whitley", "whtl");
  addMarker(40.74530000, -84.93800000, "Adams", "ada");
  addMarker(41.09380000, -85.07070000, "Allen", "all");
  addMarker(39.19300000, -85.88520000, "Bartholomew", "bar");
  addMarker(40.60630000, -87.31000000, "Benton", "ben");
  addMarker(40.47270000, -85.32390000, "Blackford", "bla");
  addMarker(40.05180000, -86.46830000, "Boone", "boo");
  addMarker(39.19630000, -86.23020000, "Brown", "bro");
  addMarker(40.58430000, -86.57400000, "Carroll", "car");
  addMarker(40.73610000, -86.37340000, "Cass", "cas");
  addMarker(38.43700000, -85.70500000, "Clark", "clar");
  addMarker(39.38750000, -87.09040000, "Clay", "clay");
  addMarker(40.30450000, -86.46910000, "Clinton", "cli");
  addMarker(38.26410000, -86.46350000, "Crawford", "cra");
  addMarker(38.69730000, -87.09180000, "Daviess", "dav");
  addMarker(39.12120000, -84.97600000, "Dearborn", "dea");
  addMarker(39.29200000, -85.49180000, "Decatur", "dec");
  addMarker(41.39730000, -84.99880000, "DeKalb", "dek");
  addMarker(40.22800000, -85.39670000, "Delaware", "del");
  addMarker(38.36480000, -86.87610000, "Dubois", "dub");
  addMarker(41.59770000, -85.85950000, "Elkhart", "elk");
  addMarker(39.65700000, -85.16800000, "Fayette", "fay");
  addMarker(38.29830000, -85.89700000, "Floyd", "flo");
  addMarker(40.15960000, -87.26510000, "Fountain", "fou");
  addMarker(39.39750000, -85.05700000, "Franklin", "fra");
  addMarker(41.04100000, -86.20690000, "Fulton", "ful");
  addMarker(38.34950000, -87.64670000, "Gibson", "gib");
  addMarker(40.51600000, -85.65460000, "Grant", "gra");
  addMarker(39.03710000, -86.96160000, "Greene", "gre");
  addMarker(40.07250000, -86.05230000, "Hamilton", "ham");
  addMarker(39.82150000, -85.76520000, "Hancock", "han");
  addMarker(38.19040000, -86.11530000, "Harrison", "har");
  addMarker(39.76240000, -86.51040000, "Hendricks", "hend");
  addMarker(39.93180000, -85.39860000, "Henry", "henr");
  addMarker(40.46970000, -86.11900000, "Howard", "how");
  addMarker(40.82910000, -85.48920000, "Huntington", "hun");
  addMarker(38.89780000, -86.05670000, "Jackson", "jac");
  addMarker(41.01140000, -87.10330000, "Jasper", "jas");
  addMarker(40.43950000, -85.01110000, "Jay", "jay");
  addMarker(38.75010000, -85.44270000, "Jefferson", "jef");
  addMarker(39.00130000, -85.61990000, "Jennings", "jen");
  addMarker(39.49000000, -86.10120000, "Johnson", "joh");
  addMarker(38.66100000, -87.41760000, "Knox", "kno");
  addMarker(41.23940000, -85.86430000, "Kosciusko", "kos");
  addMarker(41.64170000, -85.42680000, "Lagrange", "lag");
  addMarker(41.43610000, -87.37280000, "Lake", "lak");
  addMarker(41.49860000, -86.70960000, "LaPorte", "lap");
  addMarker(38.83950000, -86.47940000, "Lawrence", "law");
  addMarker(40.16170000, -85.71970000, "Madison", "mad");
  addMarker(39.77950000, -86.13280000, "Marion", "mari");
  addMarker(41.32550000, -86.26060000, "Marshall", "mars");
  addMarker(38.69980000, -86.80340000, "Martin", "mart");
  addMarker(40.78100000, -86.01650000, "Miami", "mia");
  addMarker(39.17330000, -86.50160000, "Monroe", "monr");
  addMarker(40.04000000, -86.89360000, "Montgomery", "mont");
  addMarker(39.48600000, -86.46870000, "Morgan", "mor");
  addMarker(40.97760000, -87.39700000, "Newton", "new");
  addMarker(41.39530000, -85.42350000, "Noble", "nob");
  addMarker(38.96590000, -84.98510000, "Ohio", "ohi");
  addMarker(38.54140000, -86.49530000, "Orange", "ora");
  addMarker(39.31950000, -86.84270000, "Owen", "owe");
  addMarker(39.77910000, -87.22180000, "Parke", "par");
  addMarker(38.05390000, -86.62200000, "Perry", "per");
  addMarker(38.39160000, -87.26770000, "Pike", "pik");
  addMarker(41.46540000, -87.07590000, "Porter", "por");
  addMarker(38.00100000, -87.87330000, "Posey", "pos");
  addMarker(41.04110000, -86.69900000, "Pulaski", "pul");
  addMarker(39.66840000, -86.82840000, "Putnam", "put");
  addMarker(40.15720000, -85.01130000, "Randolph", "ran");
  addMarker(39.11150000, -85.25510000, "Ripley", "rip");
  addMarker(39.61990000, -85.46550000, "Rush", "rus");
  addMarker(38.69630000, -85.72920000, "Scott", "sco");
  addMarker(39.52320000, -85.79150000, "Shelby", "she");
  addMarker(37.99380000, -87.01700000, "Spencer", "spe");
  addMarker(41.59670000, -86.29300000, "St.Joseph", "stj");
  addMarker(41.30220000, -86.69830000, "Starke", "sta");
  addMarker(41.64350000, -85.00070000, "Steuben", "ste");
  addMarker(39.08050000, -87.44320000, "Sullivan", "sul");
  addMarker(38.80860000, -84.99410000, "Switzerland", "swi");
  addMarker(40.38860000, -86.89490000, "Tippecanoe", "tipp");
  addMarker(40.31140000, -86.05170000, "Tipton", "tipt");
  addMarker(39.62550000, -84.92520000, "Union", "uni");
  addMarker(37.99720000, -87.57500000, "Vanderburgh", "van");
  addMarker(39.87780000, -87.44350000, "Vermillion", "ver");
  addMarker(39.43360000, -87.40450000, "Vigo", "vig");
  addMarker(40.84890000, -85.79250000, "Wabash", "wab");
  addMarker(40.30230000, -87.31160000, "Warren", "warn");
  addMarker(38.06250000, -87.24520000, "Warrick", "wark");
  addMarker(38.60070000, -86.07880000, "Washington", "was");
  addMarker(39.86040000, -85.01600000, "Wayne", "way");
  addMarker(40.74230000, -85.25870000, "Wells", "wel");
  addMarker(40.73700000, -86.84010000, "White", "whte");
  addMarker(41.14860000, -85.49720000, "Whitley", "whtl");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

